pub struct Status {
pub code: i32,
pub message: String,
}Expand description
OTLP Status message
Fields
code: i32message: StringImplementations
Sourceimpl Status
impl Status
Sourcepub fn code(&self) -> StatusCode
pub fn code(&self) -> StatusCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: StatusCode)
pub fn set_code(&mut self, value: StatusCode)
Sets code to the provided enum value.