pub struct DiffFilesResponse {
pub file1_path: PathBuf,
pub file2_path: PathBuf,
pub hunks: Vec<DiffHunk>,
pub added_lines: usize,
pub removed_lines: usize,
pub is_binary: bool,
}Expand description
Response structure for diff_files
Fields
file1_path: PathBuffile2_path: PathBufhunks: Vec<DiffHunk>added_lines: usizeremoved_lines: usizeis_binary: boolTrait Implementations
Sourceimpl Clone for DiffFilesResponse
impl Clone for DiffFilesResponse
Sourcefn clone(&self) -> DiffFilesResponse
fn clone(&self) -> DiffFilesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiffFilesResponse
impl Debug for DiffFilesResponse
Sourceimpl<'de> Deserialize<'de> for DiffFilesResponse
impl<'de> Deserialize<'de> for DiffFilesResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DiffFilesResponse
impl JsonSchema for DiffFilesResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiffFilesResponse
impl RefUnwindSafe for DiffFilesResponse
impl Send for DiffFilesResponse
impl Sync for DiffFilesResponse
impl Unpin for DiffFilesResponse
impl UnsafeUnpin for DiffFilesResponse
impl UnwindSafe for DiffFilesResponse