pub struct GetFileMetadataResponse {
pub path: PathBuf,
pub size: u64,
pub modified: u64,
pub is_symlink: bool,
pub language: Option<String>,
}Expand description
Response structure for get_file_metadata
Fields
path: PathBufsize: u64modified: u64is_symlink: boollanguage: Option<String>Trait Implementations
Sourceimpl Clone for GetFileMetadataResponse
impl Clone for GetFileMetadataResponse
Sourcefn clone(&self) -> GetFileMetadataResponse
fn clone(&self) -> GetFileMetadataResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetFileMetadataResponse
impl Debug for GetFileMetadataResponse
Sourceimpl<'de> Deserialize<'de> for GetFileMetadataResponse
impl<'de> Deserialize<'de> for GetFileMetadataResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetFileMetadataResponse
impl JsonSchema for GetFileMetadataResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetFileMetadataResponse
impl RefUnwindSafe for GetFileMetadataResponse
impl Send for GetFileMetadataResponse
impl Sync for GetFileMetadataResponse
impl Unpin for GetFileMetadataResponse
impl UnsafeUnpin for GetFileMetadataResponse
impl UnwindSafe for GetFileMetadataResponse