pub struct SearchCodebaseRequest {
pub path: PathBuf,
pub query: String,
pub max_results: Option<u32>,
pub file_pattern: Option<String>,
}Expand description
Request structure for search_codebase
Fields
path: PathBufquery: Stringmax_results: Option<u32>file_pattern: Option<String>Trait Implementations
Sourceimpl Clone for SearchCodebaseRequest
impl Clone for SearchCodebaseRequest
Sourcefn clone(&self) -> SearchCodebaseRequest
fn clone(&self) -> SearchCodebaseRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchCodebaseRequest
impl Debug for SearchCodebaseRequest
Sourceimpl<'de> Deserialize<'de> for SearchCodebaseRequest
impl<'de> Deserialize<'de> for SearchCodebaseRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SearchCodebaseRequest
impl JsonSchema for SearchCodebaseRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SearchCodebaseRequest
impl RefUnwindSafe for SearchCodebaseRequest
impl Send for SearchCodebaseRequest
impl Sync for SearchCodebaseRequest
impl Unpin for SearchCodebaseRequest
impl UnsafeUnpin for SearchCodebaseRequest
impl UnwindSafe for SearchCodebaseRequest