pub struct SearchCodebaseResponse {
pub results: Vec<SearchResult>,
pub total_matches: usize,
pub files_searched: usize,
pub search_time_ms: u64,
}Expand description
Response structure for search_codebase
Fields
results: Vec<SearchResult>total_matches: usizefiles_searched: usizesearch_time_ms: u64Trait Implementations
Sourceimpl Clone for SearchCodebaseResponse
impl Clone for SearchCodebaseResponse
Sourcefn clone(&self) -> SearchCodebaseResponse
fn clone(&self) -> SearchCodebaseResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchCodebaseResponse
impl Debug for SearchCodebaseResponse
Sourceimpl<'de> Deserialize<'de> for SearchCodebaseResponse
impl<'de> Deserialize<'de> for SearchCodebaseResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SearchCodebaseResponse
impl JsonSchema for SearchCodebaseResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SearchCodebaseResponse
impl RefUnwindSafe for SearchCodebaseResponse
impl Send for SearchCodebaseResponse
impl Sync for SearchCodebaseResponse
impl Unpin for SearchCodebaseResponse
impl UnsafeUnpin for SearchCodebaseResponse
impl UnwindSafe for SearchCodebaseResponse