pub struct SemanticSearchResponse {
pub results: Vec<SemanticSearchResult>,
pub total_matches: usize,
pub files_analyzed: usize,
pub search_time_ms: u64,
}Expand description
Response structure for semantic_search
Fields
results: Vec<SemanticSearchResult>total_matches: usizefiles_analyzed: usizesearch_time_ms: u64Trait Implementations
Sourceimpl Clone for SemanticSearchResponse
impl Clone for SemanticSearchResponse
Sourcefn clone(&self) -> SemanticSearchResponse
fn clone(&self) -> SemanticSearchResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticSearchResponse
impl Debug for SemanticSearchResponse
Sourceimpl<'de> Deserialize<'de> for SemanticSearchResponse
impl<'de> Deserialize<'de> for SemanticSearchResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SemanticSearchResponse
impl JsonSchema for SemanticSearchResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SemanticSearchResponse
impl RefUnwindSafe for SemanticSearchResponse
impl Send for SemanticSearchResponse
impl Sync for SemanticSearchResponse
impl Unpin for SemanticSearchResponse
impl UnsafeUnpin for SemanticSearchResponse
impl UnwindSafe for SemanticSearchResponse