pub struct SemanticSearchResult {
pub file_path: PathBuf,
pub symbol_name: String,
pub symbol_type: String,
pub line_number: usize,
pub context: String,
}Expand description
Semantic search result
Fields
file_path: PathBufsymbol_name: Stringsymbol_type: Stringline_number: usizecontext: StringTrait Implementations
Sourceimpl Clone for SemanticSearchResult
impl Clone for SemanticSearchResult
Sourcefn clone(&self) -> SemanticSearchResult
fn clone(&self) -> SemanticSearchResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticSearchResult
impl Debug for SemanticSearchResult
Sourceimpl<'de> Deserialize<'de> for SemanticSearchResult
impl<'de> Deserialize<'de> for SemanticSearchResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SemanticSearchResult
impl JsonSchema for SemanticSearchResult
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SemanticSearchResult
impl RefUnwindSafe for SemanticSearchResult
impl Send for SemanticSearchResult
impl Sync for SemanticSearchResult
impl Unpin for SemanticSearchResult
impl UnsafeUnpin for SemanticSearchResult
impl UnwindSafe for SemanticSearchResult