Module git

Module git 

Git utilities for executing git commands and parsing output

Structs

CommitInfo
Information about a single commit
DiffStats
Statistics from a git diff operation
GitContext
Git context for a file containing recent commit history

Functions

format_git_context_to_markdown
Format git context as markdown string
get_changed_files
Get the list of files changed between two git references
get_diff_stats
Get diff statistics between two git references
get_file_git_context
Get git context (recent commits) for a specific file
get_file_git_context_with_depth
Get git context (recent commits) for a specific file with configurable depth
get_repository_root
Get the root directory of the git repository
is_git_repository
Check if a directory is a git repository