Git utilities for executing git commands and parsing output
Structs
- Commit
Info - Information about a single commit
- Diff
Stats - Statistics from a git diff operation
- GitContext
- Git context for a file containing recent commit history
Functions
- format_
git_ context_ to_ markdown - Format git context as markdown string
- get_
changed_ files - Get the list of files changed between two git references
- get_
diff_ stats - Get diff statistics between two git references
- get_
file_ git_ context - Get git context (recent commits) for a specific file
- get_
file_ git_ context_ with_ depth - Get git context (recent commits) for a specific file with configurable depth
- get_
repository_ root - Get the root directory of the git repository
- is_
git_ repository - Check if a directory is a git repository